@@ -3,10 +3,9 @@ $TRANSLATIONS = array(
 "Documents" => "Dokumentumok",
 "Can't create document" => "A dokumentum nem hozható létre",
 "You don't have permission to rename this document" => "Nincs joga ahhoz, hogy átnevezze ezt a dokumentumot",
-"File does not exist" => "A fájl nem létezik!",
 "Directory saved successfully." => "A mappát sikeresen elmentettük.",
 "An error occurred while changing directory." => "Hiba történt a másik mappára történő áttérés közben.",
-"Saved" => "Elmentve!",
+"Saved" => "Elmentve",
 "Format filter server is down or misconfigured" => "A formátumszűrő szerver nem üzemel, vagy rosszul van konfigurálva",
 "Conversion failed. Check log for details." => "Az átalakítás nem sikerült. Ellenőrizze a naplóállományban a részleteket!",
 "Saving..." => "Mentés...",
@@ -18,7 +17,7 @@ $TRANSLATIONS = array(
 "Save" => "Mentés",
 "Loading documents..." => "Dokumentumok betöltése...",
 "'.' is an invalid file name." => "'.' érvénytelen, mint fájlnév.",
-"File name cannot be empty." => "A fájlnév nem lehet üres.",
+"File name cannot be empty." => "A fájlnév nem lehet semmi.",
 "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Érvénytelen elnevezés. Ezek a karakterek nem használhatók: '\\', '/', '<', '>', ':', '\"', '|', '?' és '*'",
 "Align Left" => "Balra igazítás",
 "Alignment" => "Igazítás",
